==> libreoffice-still-sdk-6.1.5-3-x86_64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html",children:[
{text:"a",url:"namespacemembers.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"i",url:"namespacemembers_i.html#index_i"},
{text:"j",url:"namespacemembers_j.html#index_j"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"q",url:"namespacemembers_q.html#index_q"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"u",url:"namespacemembers_u.html#index_u"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"x",url:"namespacemembers_x.html#index_x"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"Variables",url:"namespacemembers_vars.html",children:[
{text:"a",url:"namespacemembers_vars.html#index_a"},
{text:"b",url:"namespacemembers_vars_b.html#index_b"},
{text:"c",url:"namespacemembers_vars_c.html#index_c"},
{text:"d",url:"namespacemembers_vars_d.html#index_d"},
{text:"e",url:"namespacemembers_vars_e.html#index_e"},
{text:"f",url:"namespacemembers_vars_f.html#index_f"},
{text:"g",url:"namespacemembers_vars_g.html#index_g"},
{text:"h",url:"namespacemembers_vars_h.html#index_h"},
{text:"i",url:"namespacemembers_vars_i.html#index_i"},
{text:"j",url:"namespacemembers_vars_j.html#index_j"},
{text:"k",url:"namespacemembers_vars_k.html#index_k"},
{text:"l",url:"namespacemembers_vars_l.html#index_l"},
{text:"m",url:"namespacemembers_vars_m.html#index_m"},
{text:"n",url:"namespacemembers_vars_n.html#index_n"},
{text:"o",url:"namespacemembers_vars_o.html#index_o"},
{text:"p",url:"namespacemembers_vars_p.html#index_p"},
{text:"q",url:"namespacemembers_vars_q.html#index_q"},
{text:"r",url:"namespacemembers_vars_r.html#index_r"},
{text:"s",url:"namespacemembers_vars_s.html#index_s"},
{text:"t",url:"namespacemembers_vars_t.html#index_t"},
{text:"u",url:"namespacemembers_vars_u.html#index_u"},
{text:"v",url:"namespacemembers_vars_v.html#index_v"},
{text:"w",url:"namespacemembers_vars_w.html#index_w"},
{text:"x",url:"namespacemembers_vars_x.html#index_x"},
{text:"y",url:"namespacemembers_vars_y.html#index_y"},
{text:"z",url:"namespacemembers_vars_z.html#index_z"}]},
{text:"Typedefs",url:"namespacemembers_type.html"},
{text:"Enumerations",url:"namespacemembers_enum.html",children:[
{text:"a",url:"namespacemembers_enum.html#index_a"},
{text:"b",url:"namespacemembers_enum.html#index_b"},
{text:"c",url:"namespacemembers_enum.html#index_c"},
{text:"d",url:"namespacemembers_enum.html#index_d"},
{text:"e",url:"namespacemembers_enum.html#index_e"},
{text:"f",url:"namespacemembers_enum.html#index_f"},
{text:"g",url:"namespacemembers_enum.html#index_g"},
{text:"h",url:"namespacemembers_enum.html#index_h"},
{text:"i",url:"namespacemembers_enum.html#index_i"},
{text:"l",url:"namespacemembers_enum.html#index_l"},
{text:"m",url:"namespacemembers_enum.html#index_m"},
{text:"n",url:"namespacemembers_enum.html#index_n"},
{text:"o",url:"namespacemembers_enum.html#index_o"},
{text:"p",url:"namespacemembers_enum.html#index_p"},
{text:"r",url:"namespacemembers_enum.html#index_r"},
{text:"s",url:"namespacemembers_enum.html#index_s"},
{text:"t",url:"namespacemembers_enum.html#index_t"},
{text:"u",url:"namespacemembers_enum.html#index_u"},
{text:"v",url:"namespacemembers_enum.html#index_v"},
{text:"w",url:"namespacemembers_enum.html#index_w"},
{text:"x",url:"namespacemembers_enum.html#index_x"},
{text:"z",url:"namespacemembers_enum.html#index_z"}]},
{text:"Enumerator",url:"namespacemembers_eval.html",children:[
{text:"a",url:"namespacemembers_eval.html#index_a"},
{text:"b",url:"namespacemembers_eval_b.html#index_b"},
{text:"c",url:"namespacemembers_eval_c.html#index_c"},
{text:"d",url:"namespacemembers_eval_d.html#index_d"},
{text:"e",url:"namespacemembers_eval_e.html#index_e"},
{text:"f",url:"namespacemembers_eval_f.html#index_f"},
{text:"g",url:"namespacemembers_eval_g.html#index_g"},
{text:"h",url:"namespacemembers_eval_h.html#index_h"},
{text:"i",url:"namespacemembers_eval_i.html#index_i"},
{text:"j",url:"namespacemembers_eval_j.html#index_j"},
{text:"k",url:"namespacemembers_eval_k.html#index_k"},
{text:"l",url:"namespacemembers_eval_l.html#index_l"},
{text:"m",url:"namespacemembers_eval_m.html#index_m"},
{text:"n",url:"namespacemembers_eval_n.html#index_n"},
{text:"o",url:"namespacemembers_eval_o.html#index_o"},
{text:"p",url:"namespacemembers_eval_p.html#index_p"},
{text:"q",url:"namespacemembers_eval_q.html#index_q"},
{text:"r",url:"namespacemembers_eval_r.html#index_r"},
{text:"s",url:"namespacemembers_eval_s.html#index_s"},
{text:"t",url:"namespacemembers_eval_t.html#index_t"},
{text:"u",url:"namespacemembers_eval_u.html#index_u"},
{text:"v",url:"namespacemembers_eval_v.html#index_v"},
{text:"w",url:"namespacemembers_eval_w.html#index_w"},
{text:"x",url:"namespacemembers_eval_x.html#index_x"},
{text:"y",url:"namespacemembers_eval_y.html#index_y"},
{text:"z",url:"namespacemembers_eval_z.html#index_z"}]}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:":",url:"functions.html#index_:"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"a",url:"functions_type.html#index_a"},
{text:"b",url:"functions_type.html#index_b"},
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"e",url:"functions_type.html#index_e"},
{text:"f",url:"functions_type.html#index_f"},
{text:"g",url:"functions_type.html#index_g"},
{text:"h",url:"functions_type.html#index_h"},
{text:"i",url:"functions_type.html#index_i"},
{text:"k",url:"functions_type.html#index_k"},
{text:"l",url:"functions_type.html#index_l"},
{text:"m",url:"functions_type.html#index_m"},
{text:"n",url:"functions_type.html#index_n"},
{text:"o",url:"functions_type.html#index_o"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"u",url:"functions_type.html#index_u"},
{text:"v",url:"functions_type.html#index_v"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"}]}]}]}]}

==> libreoffice-still-sdk-6.2.7-3-x86_64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/menudata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html",children:[
{text:"a",url:"namespacemembers.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"i",url:"namespacemembers_i.html#index_i"},
{text:"j",url:"namespacemembers_j.html#index_j"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"q",url:"namespacemembers_q.html#index_q"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"u",url:"namespacemembers_u.html#index_u"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"x",url:"namespacemembers_x.html#index_x"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"Variables",url:"namespacemembers_vars.html",children:[
{text:"a",url:"namespacemembers_vars.html#index_a"},
{text:"b",url:"namespacemembers_vars_b.html#index_b"},
{text:"c",url:"namespacemembers_vars_c.html#index_c"},
{text:"d",url:"namespacemembers_vars_d.html#index_d"},
{text:"e",url:"namespacemembers_vars_e.html#index_e"},
{text:"f",url:"namespacemembers_vars_f.html#index_f"},
{text:"g",url:"namespacemembers_vars_g.html#index_g"},
{text:"h",url:"namespacemembers_vars_h.html#index_h"},
{text:"i",url:"namespacemembers_vars_i.html#index_i"},
{text:"j",url:"namespacemembers_vars_j.html#index_j"},
{text:"k",url:"namespacemembers_vars_k.html#index_k"},
{text:"l",url:"namespacemembers_vars_l.html#index_l"},
{text:"m",url:"namespacemembers_vars_m.html#index_m"},
{text:"n",url:"namespacemembers_vars_n.html#index_n"},
{text:"o",url:"namespacemembers_vars_o.html#index_o"},
{text:"p",url:"namespacemembers_vars_p.html#index_p"},
{text:"q",url:"namespacemembers_vars_q.html#index_q"},
{text:"r",url:"namespacemembers_vars_r.html#index_r"},
{text:"s",url:"namespacemembers_vars_s.html#index_s"},
{text:"t",url:"namespacemembers_vars_t.html#index_t"},
{text:"u",url:"namespacemembers_vars_u.html#index_u"},
{text:"v",url:"namespacemembers_vars_v.html#index_v"},
{text:"w",url:"namespacemembers_vars_w.html#index_w"},
{text:"x",url:"namespacemembers_vars_x.html#index_x"},
{text:"y",url:"namespacemembers_vars_y.html#index_y"},
{text:"z",url:"namespacemembers_vars_z.html#index_z"}]},
{text:"Typedefs",url:"namespacemembers_type.html"},
{text:"Enumerations",url:"namespacemembers_enum.html",children:[
{text:"a",url:"namespacemembers_enum.html#index_a"},
{text:"b",url:"namespacemembers_enum.html#index_b"},
{text:"c",url:"namespacemembers_enum.html#index_c"},
{text:"d",url:"namespacemembers_enum.html#index_d"},
{text:"e",url:"namespacemembers_enum.html#index_e"},
{text:"f",url:"namespacemembers_enum.html#index_f"},
{text:"g",url:"namespacemembers_enum.html#index_g"},
{text:"h",url:"namespacemembers_enum.html#index_h"},
{text:"i",url:"namespacemembers_enum.html#index_i"},
{text:"l",url:"namespacemembers_enum.html#index_l"},
{text:"m",url:"namespacemembers_enum.html#index_m"},
{text:"n",url:"namespacemembers_enum.html#index_n"},
{text:"o",url:"namespacemembers_enum.html#index_o"},
{text:"p",url:"namespacemembers_enum.html#index_p"},
{text:"r",url:"namespacemembers_enum.html#index_r"},
{text:"s",url:"namespacemembers_enum.html#index_s"},
{text:"t",url:"namespacemembers_enum.html#index_t"},
{text:"u",url:"namespacemembers_enum.html#index_u"},
{text:"v",url:"namespacemembers_enum.html#index_v"},
{text:"w",url:"namespacemembers_enum.html#index_w"},
{text:"x",url:"namespacemembers_enum.html#index_x"},
{text:"z",url:"namespacemembers_enum.html#index_z"}]},
{text:"Enumerator",url:"namespacemembers_eval.html",children:[
{text:"a",url:"namespacemembers_eval.html#index_a"},
{text:"b",url:"namespacemembers_eval_b.html#index_b"},
{text:"c",url:"namespacemembers_eval_c.html#index_c"},
{text:"d",url:"namespacemembers_eval_d.html#index_d"},
{text:"e",url:"namespacemembers_eval_e.html#index_e"},
{text:"f",url:"namespacemembers_eval_f.html#index_f"},
{text:"g",url:"namespacemembers_eval_g.html#index_g"},
{text:"h",url:"namespacemembers_eval_h.html#index_h"},
{text:"i",url:"namespacemembers_eval_i.html#index_i"},
{text:"j",url:"namespacemembers_eval_j.html#index_j"},
{text:"k",url:"namespacemembers_eval_k.html#index_k"},
{text:"l",url:"namespacemembers_eval_l.html#index_l"},
{text:"m",url:"namespacemembers_eval_m.html#index_m"},
{text:"n",url:"namespacemembers_eval_n.html#index_n"},
{text:"o",url:"namespacemembers_eval_o.html#index_o"},
{text:"p",url:"namespacemembers_eval_p.html#index_p"},
{text:"q",url:"namespacemembers_eval_q.html#index_q"},
{text:"r",url:"namespacemembers_eval_r.html#index_r"},
{text:"s",url:"namespacemembers_eval_s.html#index_s"},
{text:"t",url:"namespacemembers_eval_t.html#index_t"},
{text:"u",url:"namespacemembers_eval_u.html#index_u"},
{text:"v",url:"namespacemembers_eval_v.html#index_v"},
{text:"w",url:"namespacemembers_eval_w.html#index_w"},
{text:"x",url:"namespacemembers_eval_x.html#index_x"},
{text:"y",url:"namespacemembers_eval_y.html#index_y"},
{text:"z",url:"namespacemembers_eval_z.html#index_z"}]}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:":",url:"functions.html#index_:"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"a",url:"functions_type.html#index_a"},
{text:"b",url:"functions_type.html#index_b"},
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"e",url:"functions_type.html#index_e"},
{text:"f",url:"functions_type.html#index_f"},
{text:"g",url:"functions_type.html#index_g"},
{text:"h",url:"functions_type.html#index_h"},
{text:"i",url:"functions_type.html#index_i"},
{text:"k",url:"functions_type.html#index_k"},
{text:"l",url:"functions_type.html#index_l"},
{text:"m",url:"functions_type.html#index_m"},
{text:"n",url:"functions_type.html#index_n"},
{text:"o",url:"functions_type.html#index_o"},
{text:"p",url:"functions_type.html#index_p"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"u",url:"functions_type.html#index_u"},
{text:"v",url:"functions_type.html#index_v"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"}]}]}]}]}
